ledger.AccountingPeriod (Accounting period) — amici1

# `ledger.AccountingPeriod` (Accounting period)

AccountingPeriod(id, ref, start_date, end_date, state, year, remark)

Master tables : ledger.AccountingPeriods (Accounting periods)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- Start date (start_date) : See `<django.db.models.fields.DateField: start_date>`.

- End date (end_date) : See `<django.db.models.fields.DateField: end_date>`.

- State (state) : See `<lino.core.choicelists.ChoiceListField: state>`.

- Fiscal year (year) : See `<django.db.models.fields.related.ForeignKey: year>`.

- Remark (remark) : See `<django.db.models.fields.CharField: remark>`.

- Name (name_column) : See `lino_xl.lib.ledger.models.AccountingPeriod.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.AccountingPeriod.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.AccountingPeriod.overview`.

Referenced from ledger.Voucher.accounting_period

## Database fields

Internal name | Verbose name | Help text
id | ID |
ref | Reference | The reference. This must be either empty or unique.
start_date | Start date |
end_date | End date |
state | State |
year | Fiscal year |
remark | Remark |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |